@@ -32,7 +32,6 @@ from localstack.utils.aws.dead_letter_queue import (
     lambda_error_to_dead_letter_queue,
     sqs_error_to_dead_letter_queue,
 )
-from localstack.utils.aws.lambda_destinations import lambda_result_to_destination
 from localstack.utils.cloudwatch.cloudwatch_util import cloudwatched
 from localstack.utils.common import (
     TMP_FILES,
@@ -53,7 +52,7 @@ from localstack.utils.common import (
     to_bytes,
     to_str,
 )
-from localstack.utils.docker import DOCKER_CLIENT, ContainerException, PortMappings
+from localstack.utils.docker_utils import DOCKER_CLIENT, ContainerException, PortMappings
 from localstack.utils.run import FuncThread
 
 # constants
@@ -375,6 +374,9 @@ class LambdaExecutor(object):
         callback: Callable = None,
         lock_discriminator: str = None,
     ):
+        # note: leave here to avoid circular import issues
+        from localstack.utils.aws.message_forwarding import lambda_result_to_destination
+
         def do_execute(*args):
             @cloudwatched("lambda")
             def _run(func_arn=None):
@@ -1110,7 +1112,7 @@ class LambdaExecutorSeparateContainers(LambdaExecutorContainers):
 
 class LambdaExecutorLocal(LambdaExecutor):
     def _execute_in_custom_runtime(
-        self, cmd: str, lambda_function: LambdaFunction = None
+        self, cmd: Union[str, List[str]], lambda_function: LambdaFunction = None
     ) -> InvocationResult:
         """
         Generic run function for executing lambdas in custom runtimes.
@@ -1311,15 +1313,17 @@ class LambdaExecutorLocal(LambdaExecutor):
         function = handler.split(".")[-1]
         event_json_string = "%s" % (json.dumps(json_safe(event)) if event else "{}")
         context_json_string = "%s" % (json.dumps(context.__dict__) if context else "{}")
-        cmd = (
-            "node -e 'require(\"%s\").%s(%s,%s).then(r => process.stdout.write(JSON.stringify(r)))'"
+        cmd = [
+            "node",
+            "-e",
+            'require("%s").%s(%s,%s).then(r => process.stdout.write(JSON.stringify(r)))'
             % (
                 main_file,
                 function,
                 event_json_string,
                 context_json_string,
-            )
-        )
+            ),
+        ]
         LOG.info(cmd)
         result = self._execute_in_custom_runtime(cmd, lambda_function=lambda_function)
         return result
