@@ -2,6 +2,7 @@ import json
 from urllib.parse import urlparse
 
 from localstack.services.cloudformation.deployment_utils import (
+    generate_default_name,
     lambda_keys_to_lower,
     params_list_to_dict,
 )
@@ -57,6 +58,14 @@ class GatewayRequestValidator(GenericBaseModel):
         result = [r for r in result if r.get("name") == name]
         return result[0] if result else None
 
+    @staticmethod
+    def add_defaults(resource, stack_name: str):
+        role_name = resource["Properties"].get("Name")
+        if not role_name:
+            resource["Properties"]["Name"] = generate_default_name(
+                stack_name, resource["LogicalResourceId"]
+            )
+
     @staticmethod
     def get_deploy_templates():
         return {
@@ -91,6 +100,14 @@ class GatewayRestAPI(GenericBaseModel):
         result = list(filter(lambda api: api["name"] == api_name, apis))
         return result[0] if result else None
 
+    @staticmethod
+    def add_defaults(resource, stack_name: str):
+        role_name = resource.get("Properties", {}).get("Name")
+        if not role_name:
+            resource["Properties"]["Name"] = generate_default_name(
+                stack_name, resource["LogicalResourceId"]
+            )
+
     @classmethod
     def get_deploy_templates(cls):
         def _api_id(params, resources, resource_id, **kwargs):
@@ -398,11 +415,12 @@ class GatewayStage(GenericBaseModel):
 
     @staticmethod
     def get_deploy_templates():
-        def get_params(params, **kwargs):
-            result = keys_to_lower(params)
+        def get_params(resource_props, stack_name, resources, resource_id):
+            stage_name = resource_props.get("StageName", "default")
+            resources[resource_id]["Properties"]["StageName"] = stage_name
+            result = keys_to_lower(resource_props)
             param_names = [
                 "restApiId",
-                "stageName",
                 "deploymentId",
                 "description",
                 "cacheClusterEnabled",
@@ -415,9 +433,15 @@ class GatewayStage(GenericBaseModel):
             ]
             result = select_attributes(result, param_names)
             result["tags"] = {t["key"]: t["value"] for t in result.get("tags", [])}
+            result["stageName"] = stage_name
             return result
 
-        return {"create": {"function": "create_stage", "parameters": get_params}}
+        return {
+            "create": {
+                "function": "create_stage",
+                "parameters": get_params,
+            }
+        }
 
 
 class GatewayUsagePlan(GenericBaseModel):
@@ -432,6 +456,14 @@ class GatewayUsagePlan(GenericBaseModel):
         result = [r for r in result if r["name"] == plan_name]
         return (result or [None])[0]
 
+    @staticmethod
+    def add_defaults(resource, stack_name: str):
+        role_name = resource.get("Properties", {}).get("UsagePlanName")
+        if not role_name:
+            resource["Properties"]["UsagePlanName"] = generate_default_name(
+                stack_name, resource["LogicalResourceId"]
+            )
+
     @staticmethod
     def get_deploy_templates():
         return {
@@ -469,6 +501,14 @@ class GatewayApiKey(GenericBaseModel):
         ]
         return (result or [None])[0]
 
+    @staticmethod
+    def add_defaults(resource, stack_name: str):
+        role_name = resource.get("Properties", {}).get("Name")
+        if not role_name:
+            resource["Properties"]["Name"] = generate_default_name(
+                stack_name, resource["LogicalResourceId"]
+            )
+
     @staticmethod
     def get_deploy_templates():
         return {
@@ -604,6 +644,14 @@ class GatewayModel(GenericBaseModel):
 
         return None
 
+    @staticmethod
+    def add_defaults(resource, stack_name: str):
+        role_name = resource.get("Properties", {}).get("Name")
+        if not role_name:
+            resource["Properties"]["Name"] = generate_default_name(
+                stack_name, resource["LogicalResourceId"]
+            )
+
     @staticmethod
     def get_deploy_templates():
         return {
