@@ -1,5 +1,6 @@
 from moto.ec2.utils import generate_route_id
 
+from localstack.services.cloudformation.deployment_utils import generate_default_name
 from localstack.services.cloudformation.service_models import REF_ID_ATTRS, GenericBaseModel
 from localstack.utils.aws import aws_stack
 
@@ -237,6 +238,14 @@ class SecurityGroup(GenericBaseModel):
             props = self.props
             return props.get("GroupId") or props.get("GroupName")
 
+    @staticmethod
+    def add_defaults(resource, stack_name: str):
+        role_name = resource.get("Properties", {}).get("GroupName")
+        if not role_name:
+            resource["Properties"]["GroupName"] = generate_default_name(
+                stack_name, resource["LogicalResourceId"]
+            )
+
     @staticmethod
     def get_deploy_templates():
         return {
@@ -304,8 +313,22 @@ class EC2VPC(GenericBaseModel):
         resp = client.describe_vpcs(Filters=[{"Name": "cidr", "Values": [self.props["CidrBlock"]]}])
         return (resp["Vpcs"] or [None])[0]
 
-    @staticmethod
-    def get_deploy_templates():
+    @classmethod
+    def get_deploy_templates(cls):
+        def _pre_delete(resource_id, resources, resource_type, func, stack_name):
+            res = cls(resources[resource_id])
+            vpc_id = res.state.get("VpcId")
+            if vpc_id:
+                ec2_client = aws_stack.connect_to_service("ec2")
+                resp = ec2_client.describe_route_tables(
+                    Filters=[
+                        {"Name": "vpc-id", "Values": [vpc_id]},
+                        {"Name": "association.main", "Values": ["false"]},
+                    ]
+                )
+                for rt in resp["RouteTables"]:
+                    ec2_client.delete_route_table(RouteTableId=rt["RouteTableId"])
+
         return {
             "create": {
                 "function": "create_vpc",
@@ -315,10 +338,13 @@ class EC2VPC(GenericBaseModel):
                     # TODO: add TagSpecifications
                 },
             },
-            "delete": {
-                "function": "delete_vpc",
-                "parameters": {"VpcId": "PhysicalResourceId"},
-            },
+            "delete": [
+                {"function": _pre_delete},
+                {
+                    "function": "delete_vpc",
+                    "parameters": {"VpcId": "PhysicalResourceId"},
+                },
+            ],
         }
 
     def get_physical_resource_id(self, attribute=None, **kwargs):
