@@ -2,6 +2,7 @@ import json
 import logging
 import os
 import re
+from typing import Optional
 
 import boto3
 import moto.cloudformation.utils
@@ -25,21 +26,21 @@ NoDatesSafeLoader.yaml_implicit_resolvers = {
 }
 
 
-def transform_template(req_data):
+def transform_template(req_data) -> Optional[str]:
+    """only returns string when parsing SAM template, otherwise None"""
     template_body = get_template_body(req_data)
     parsed = parse_template(template_body)
-
-    policy_map = {
-        # SAM Transformer expects this map to be non-empty, but apparently the content doesn't matter (?)
-        "dummy": "entry"
-        # 'AWSLambdaBasicExecutionRole': 'arn:aws:iam::aws:policy/service-role/AWSLambdaBasicExecutionRole',
-    }
-
-    class MockPolicyLoader(object):
-        def load(self):
-            return policy_map
-
     if parsed.get("Transform") == "AWS::Serverless-2016-10-31":
+        policy_map = {
+            # SAM Transformer expects this map to be non-empty, but apparently the content doesn't matter (?)
+            "dummy": "entry"
+            # 'AWSLambdaBasicExecutionRole': 'arn:aws:iam::aws:policy/service-role/AWSLambdaBasicExecutionRole',
+        }
+
+        class MockPolicyLoader(object):
+            def load(self):
+                return policy_map
+
         # Note: we need to fix boto3 region, otherwise AWS SAM transformer fails
         region_before = os.environ.get("AWS_DEFAULT_REGION")
         if boto3.session.Session().region_name is None:
@@ -53,7 +54,7 @@ def transform_template(req_data):
                 os.environ["AWS_DEFAULT_REGION"] = region_before
 
 
-def prepare_template_body(req_data):
+def prepare_template_body(req_data) -> Optional[str]:  # TODO: mutating and returning
     template_url = req_data.get("TemplateURL")
     if template_url:
         req_data["TemplateURL"] = convert_s3_to_local_url(template_url)
@@ -141,7 +142,7 @@ def parse_template(template):
     except Exception:
         yaml.add_multi_constructor(
             "", moto.cloudformation.utils.yaml_tag_constructor, Loader=NoDatesSafeLoader
-        )
+        )  # TODO: remove moto dependency here
         try:
             return clone_safe(yaml.safe_load(template))
         except Exception:
